--
-- Migrate GH Tester database from schema version 1.9.21 to 1.9.22
--

DECLARE 
  required_version VARCHAR2(100);
  current_version VARCHAR2(100);
BEGIN
  SELECT '1.9.21' INTO required_version FROM dual;
  SELECT value INTO current_version FROM db_details 
    WHERE property='schema.version.number' 
    AND ctime = (
      SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number' 
    );
    
   IF current_version != required_version THEN
     RAISE_APPLICATION_ERROR( -20001, 
                             'Incorrect schema version: ' || current_version  ||
                             ', expected: ' || required_version );
                             
   ELSE
-- 
-- Update Script here
--
EXECUTE IMMEDIATE 'ALTER TABLE "SCENARIO_EXECUTION" RENAME TO "SE"';
EXECUTE IMMEDIATE 'ALTER TABLE "SE" DROP CONSTRAINT "SCENARIO_EXECUTION_PK"';

EXECUTE IMMEDIATE
'CREATE TABLE "SCENARIO_EXECUTION"(
    "EXECUTION_ID"  NUMBER(19, 0)    NOT NULL,
    "SCENARIO_ID"   NUMBER(19, 0)    NOT NULL,
    CONSTRAINT "SCENARIO_EXECUTION_PK" PRIMARY KEY ("EXECUTION_ID"), 
    FOREIGN KEY ("EXECUTION_ID")
    REFERENCES "EXECUTION"("ID") ON DELETE CASCADE,
    FOREIGN KEY ("SCENARIO_ID")
    REFERENCES "SCENARIO"("ID")
)';

EXECUTE IMMEDIATE 'INSERT INTO "SCENARIO_EXECUTION" SELECT * FROM "SE"';
commit;
EXECUTE IMMEDIATE 'DROP TABLE "SE"';


INSERT INTO db_details VALUES
   ( (SELECT sysdate FROM dual), 'schema.version.number','1.9.22');

commit;

   END IF; -- version check
END;
/
